# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing
from typing import Union

from pydivkit.core import BaseDiv, Expr, Field

from . import div_color_animator, div_number_animator

DivAnimator = Union[
    div_color_animator.DivColorAnimator,
    div_number_animator.DivNumberAnimator,
]
